# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/movie/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Movie\\": "packages/litecms/movie/src",
            "Litecms\\Movie\\Seeders\\": "packages/litecms/movie/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Movie\Providers\MovieServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Movie'  => Litecms\Movie\Facades\Movie::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Movie\\Seeders\\MovieTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Movie\Providers\MovieServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Movie\Providers\MovieServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Movie\Providers\MovieServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/movie/{modulename}

**User**

    http://path-to-route-folder/user/movie/{modulename}

**Public**

    http://path-to-route-folder/movies


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/movie/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/movie/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/movie/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/movie/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/movie/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/movie/{modulename}/{slug}
    METHOD: GET