<?php

namespace Litecms\Movie\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Movie\Interfaces\MovieRepositoryInterface;
use Litecms\Movie\Repositories\Eloquent\Filters\MoviePublicFilter;
use Litecms\Movie\Repositories\Eloquent\Presenters\MovieListPresenter;

class MoviePublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        MovieRepositoryInterface $movie
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.movie.modules'), 'movie', guard_url('movie'));
        $this->repository = $movie;
    }

    /**
     * Show movie's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(MoviePublicFilter::class)
            ->setPresenter(MovieListPresenter::class)
            ->select('movies.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('movie::movie.names'))
            ->view('movie::public.movie.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show movie.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('movie::movie.name'))
            ->view('movie::public.movie.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
